@@ -22,7 +22,7 @@
 //!      ```toml
 //!      # Cargo.toml
 //!      [dependencies]
-//!      pg-embed = { version = "0.4", default-features = false, features = ["rt_tokio"] }
+//!      pg-embed = { version = "0.5", default-features = false, features = ["rt_tokio"] }
 //!      ```
 //!
 //!      *Library with sqlx migration support*
@@ -30,88 +30,87 @@
 //!      ```toml
 //!      # Cargo.toml
 //!      [dependencies]
-//!      pg-embed = "0.4"
+//!      pg-embed = "0.5"
 //!      ```
 //!
 //! A postgresql instance can be created using<br/>
-//! **[PgEmbed]( postgres::PgEmbed )::new([PgSettings]( postgres::PgSettings ), [FetchSettings]( fetch::FetchSettings ))**
+//! **[PgEmbed]( postgres::PgEmbed )::new([PgSettings]( postgres::PgSettings ), [PgFetchSettings]( fetch::PgFetchSettings ))**
 //!
 //! # Examples
 //!
 //! ```
+//!
 //! use pg_embed::postgres::{PgEmbed, PgSettings, PgAuthMethod};
-//! use pg_embed::fetch;
-//! use pg_embed::fetch::{OperationSystem, Architecture, FetchSettings, PG_V13};
+//! use pg_embed::pg_fetch;
+//! use pg_embed::pg_fetch::{PgFetchSettings, PG_V13};
 //! use std::time::Duration;
+//! use std::path::PathBuf;
 //!
 //! /// Postgresql settings
 //! let pg_settings = PgSettings{
-//!     /// Where to store the postgresql executables
-//!     executables_dir: PathBuf::from("data/postgres"),
-//!     /// Where to store the postgresql database
-//!     database_dir: PathBuf::from("data/db"),
-//!     port: 5432,
-//!     user: "postgres".to_string(),
-//!     password: "password".to_string(),
-//!     /// authentication method
-//!     auth_method: PgAuthMethod::Plain,
-//!     /// If persistent is false clean up files and directories on drop, otherwise keep them
-//!     persistent: false,
-//!     start_timeout: Duration::from_secs(15),
-//!     /// If migration sql scripts need to be run, the directory containing those scripts can be
-//!     /// specified here with `Some(path_to_dir), otherwise `None` to run no migrations.
-//!     /// To enable migrations view the **Usage** section for details
-//!     migration_dir: None,
+//! // Where to store the postgresql database
+//! database_dir: PathBuf::from("data/db"),
+//! port: 5432,
+//! user: "postgres".to_string(),
+//! password: "password".to_string(),
+//! // authentication method
+//! auth_method: PgAuthMethod::Plain,
+//! // If persistent is false clean up files and directories on drop, otherwise keep them
+//! persistent: false,
+//! // duration to wait before terminating process execution
+//! // pg_ctl start/stop and initdb timeout
+//! timeout: Duration::from_secs(15),
+//! // If migration sql scripts need to be run, the directory containing those scripts can be
+//! // specified here with `Some(PathBuf(path_to_dir)), otherwise `None` to run no migrations.
+//! // To enable migrations view the **Usage** section for details
+//! migration_dir: None,
 //! };
 //!
 //! /// Postgresql binaries download settings
-//! let fetch_settings = FetchSettings{
-//!     host: "https://repo1.maven.org".to_string(),
-//!     operating_system: OperationSystem::Darwin,
-//!     architecture: Architecture::Amd64,
-//!     version: PG_V13
+//! let fetch_settings = PgFetchSettings{
+//! version: PG_V13,
+//! ..Default::default()
 //! };
 //!
-//! /// Create a new instance
-//! let mut pg = PgEmbed::new(pg_settings, fetch_settings);
 //!
 //! /// async block only to show that these methods need to be executed in an async context
 //! async {
-//!     /// Download, unpack, create password file and database cluster
-//!     pg.setup().await;
+//! // Create a new instance
+//! let mut pg = PgEmbed::new(pg_settings, fetch_settings).await?;
 //!
-//!     /// start postgresql database
-//!     pg.start_db().await;
+//! // Download, unpack, create password file and database cluster
+//! pg.setup().await;
 //!
-//!     /// create a new database
-//!     /// to enable migrations view the **Usage** section for details
-//!     pg.create_database("database_name").await;
+//! // start postgresql database
+//! pg.start_db().await;
 //!
-//!     /// drop a new database
-//!     /// to enable migrations view [Usage] for details
-//!     /// to enable migrations view the **Usage** section for details
-//!     pg.drop_database("database_name").await;
+//! // create a new database
+//! // to enable migrations view the [Usage] section for details
+//! pg.create_database("database_name").await;
 //!
-//!     /// check database existence
-//!     /// to enable migrations view [Usage] for details
-//!     /// to enable migrations view the **Usage** section for details
-//!     pg.database_exists("database_name").await;
+//! // drop a new database
+//! // to enable migrations view [Usage] for details
+//! pg.drop_database("database_name").await;
 //!
-//!     /// run migration sql scripts
-//!     /// to enable migrations view [Usage] for details
-//!     /// to enable migrations view the **Usage** section for details
-//!     pg.migrate("database_name").await;
+//! // check database existence
+//! // to enable migrations view [Usage] for details
+//! pg.database_exists("database_name").await;
+//!
+//! // run migration sql scripts
+//! // to enable migrations view [Usage] for details
+//! pg.migrate("database_name").await;
+//!
+//! // stop postgresql database
+//! pg.stop_db().await;
 //! };
-//!     /// get the base postgresql uri
-//!     /// `postgres://{username}:{password}@localhost:{port}`
-//!     let pg_uri: &str = &pg.db_uri;
+//! // get the base postgresql uri
+//! // `postgres://{username}:{password}@localhost:{port}`
+//! let pg_uri: &str = &pg.db_uri;
 //!
-//!     /// get a postgresql database uri
-//!     /// `postgres://{username}:{password}@localhost:{port}/{specified_database_name}`
-//!     let pg_db_uri: String = pg.full_db_uri("database_name");
+//! // get a postgresql database uri
+//! // `postgres://{username}:{password}@localhost:{port}/{specified_database_name}`
+//! let pg_db_uri: String = pg.full_db_uri("database_name");
 //!
-//!     /// stop postgresql database
-//!     pg.stop_db();
 //!
 //!
 //! ```
@@ -156,7 +155,11 @@ compile_error!(
      'rt_async_std', 'rt_async_std_migrate'] can be enabled"
 );
 
-pub mod fetch;
+extern crate dirs;
+pub mod pg_fetch;
 pub mod postgres;
-pub mod errors;
+pub mod pg_access;
+pub mod pg_enums;
+pub mod pg_unpack;
+pub mod pg_errors;
 
