@@ -1,4 +1,4 @@
-use pg_embed::errors::PgEmbedError;
+use pg_embed::pg_errors::PgEmbedError;
 use serial_test::serial;
 
 mod common;
@@ -8,6 +8,6 @@ mod common;
 async fn postgres_server_start_stop() -> Result<(), PgEmbedError> {
     let mut pg = common::setup().await?;
     pg.start_db().await?;
-    let _ = pg.stop_db()?;
+    pg.stop_db().await?;
     Ok(())
 }
